Declarative, reactive control trees over clj-libui.
Declarative, reactive control trees over clj-libui.
(mount! tree)(mount! tree
{:keys [backend on-error]
:or {backend native-backend on-error report-error!}})Mounts a static declarative tree on the current libui-ng thread.
Property values may be atoms. Their Missionary subscriptions remain active
until unmount!.
Mounts a static declarative tree on the current libui-ng thread. Property values may be atoms. Their Missionary subscriptions remain active until `unmount!`.
(quit!)Requests that the clj-libui event loop stop.
Requests that the clj-libui event loop stop.
(root-control mounted)Returns the mounted tree's opaque clj-libui root control.
Returns the mounted tree's opaque clj-libui root control.
(run! tree)Initializes clj-libui, mounts and shows a tree, runs the event loop, then deterministically unmounts and uninitializes it.
Initializes clj-libui, mounts and shows a tree, runs the event loop, then deterministically unmounts and uninitializes it.
(show! mounted)Shows the mounted root control.
Shows the mounted root control.
(unmount! mounted)Cancels reactive subscriptions and destroys the root exactly once.
Must run on the libui-ng thread.
Cancels reactive subscriptions and destroys the root exactly once. Must run on the libui-ng thread.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |